@@ -12,8 +12,8 @@ sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.par
 
 import base.constantes_base as cst
 
-from signaux.signal_6_sysam import Signal6Sysam
-from base.temps_base import TempsBase
+from signaux.signal_7_filtre import Signal7Filtre
+from base.axe_x_base import AxeXBase
 
 import numpy as np
 
@@ -21,23 +21,21 @@ import matplotlib.pyplot as plt
  
 __all__ = []
 
-class SignalComplet(Signal6Sysam):
+class SignalComplet(Signal7Filtre):
     pass
 
 
 if __name__ == "__main__":
-    liste_tmin_tmax=[0, 1]
-    Te = 1e-3
+    liste_xmin_xmax=[0, 1]
+    Xe = 1e-3
     F = 2
     
-    bdt = TempsBase(liste_tmin_tmax, Te)
-    vecteur_t = bdt.calculer_vecteur_t()
-    vecteur_signal = np.cos(2*np.pi*F*vecteur_t)
+    bdt = AxeXBase(liste_xmin_xmax, Xe)
+    vecteur_x = bdt.lire_vecteur_x()
+    vecteur_y = np.cos(2*np.pi*F*vecteur_x)
 
-    s = SignalComplet(bdt, vecteur_signal)
+    s = SignalComplet(bdt, vecteur_y)
     s.configurer_voie("EA0")
-    s.plot("r", label = "zorro")
-    plt.legend()
-    plt.show()
+    s.tracer()
 
     print("fin")
\ No newline at end of file
