@@ -11,22 +11,21 @@ import matplotlib.pyplot as plt
 
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 
-from base.temps_base import TempsBase
+from base.axe_x_base import AxeXBase
 from signaux.signal_complet import SignalComplet
 
 __all__ = ["SignalWav"]
 
 class SignalWav(SignalComplet):
     def __init__(self, nom_fichier_wav, Pbits = 16, liste_umin_umax = [-10, 10], nom = ""):
-        base_de_temps = TempsBase()
-        NBase = max(base_de_temps.liste_bases_de_temps_sysam)+1
-        base_de_temps._TempsBase__Nbase = NBase
-        SignalComplet.__init__(self, base_de_temps, nom)
+        SignalComplet.__init__(self, AxeXBase(), nom)
         self.lire_wav(nom_fichier_wav, Pbits, liste_umin_umax)
 
 if __name__ == "__main__":
     s1 = SignalWav('/Users/nicolas/tmp/A3.wav')
-    s1.plot()
-    plt.legend()
-    plt.show()
-    print("fin")
\ No newline at end of file
+    
+    can_base = s1._Signal4TNS__lire_can_base()
+    print(can_base.Pbits)
+    # s1.enregistrer_wav('/Users/nicolas/tmp/A3bis.wav')
+
+    # s1.tracer()
