@@ -33,36 +33,36 @@ class Sysam3Test(Sysam2Mode):
     ## tester liste signaux
     ##################################################################################################################
     def tester_liste_signaux(self):
-        # Générer Te_entrées_min
-        liste_Te = [0.]
+        # Générer Xe_entrées_min
+        liste_Xe = [0.]
         if "entree" in self.chaine_mode:
-            liste_Te.append(base.voie_base.Te_direct)
+            liste_Xe.append(base.voie_base.Xe_direct)
         if "multiplex" in self.chaine_mode:
-            liste_Te.append(base.voie_base.Te_multiplex)
+            liste_Xe.append(base.voie_base.Xe_multiplex)
         if "synchrone" in self.chaine_mode:
-            liste_Te.append(base.voie_base.Te_sortie)
-        self.Te_entree_min = np.max(liste_Te)
+            liste_Xe.append(base.voie_base.Xe_sortie)
+        self.Xe_entree_min = np.max(liste_Xe)
 
-        # Générer Te_sorties_min
-        liste_Te = [0.]
+        # Générer Xe_sorties_min
+        liste_Xe = [0.]
         if "sortie" in self.chaine_mode:
-            liste_Te.append(base.voie_base.Te_sortie)
+            liste_Xe.append(base.voie_base.Xe_sortie)
         if "multiplex" in self.chaine_mode and "synchrone" in self.chaine_mode:
-            liste_Te.append(base.voie_base.Te_multiplex)
-        self.Te_sortie_min = np.max(liste_Te)
+            liste_Xe.append(base.voie_base.Xe_multiplex)
+        self.Xe_sortie_min = np.max(liste_Xe)
 
         # Générer base de temps entrées
         if self.liste_entrees_simples:
-            self.base_de_temps_entrees = self.liste_entrees_simples[0].lire_base_de_temps()
+            self.axe_x_base_entrees = self.liste_entrees_simples[0]._PlotBase__lire_axe_x_base()
         elif self.liste_entrees_diffs:
-            self.base_de_temps_entrees = self.liste_entrees_diffs[0].lire_base_de_temps()
+            self.axe_x_base_entrees = self.liste_entrees_diffs[0]._PlotBase__lire_axe_x_base()
         else:
-            self.base_de_temps_entrees = None
+            self.axe_x_base_entrees = None
 
         # tester validite des noms des voies
         liste_signaux_noms_voies_ko = utb.lister_test(self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_sysam() and (not s.lire_voie_base().tester_nom()),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_sysam() and (not s._Signal6Sysam__lire_voie_base().tester_nom()),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_signaux_noms_voies_ko:
             print("Problème avec les noms des voies voie suivants:")
@@ -71,9 +71,9 @@ class Sysam3Test(Sysam2Mode):
 
         # tester compatibilités entre les noms des voies
         liste_paires_signaux_noms_voies_ko = utb.lister_paires_test(self.liste_signaux, 
-            lambda s1, s2: s1.lire_voie_base().tester_sysam() and s2.lire_voie_base().tester_sysam() and not s1.lire_voie_base().tester_compatibilite_nom(s2.lire_voie_base()),
-            lambda p: p[0].lire_voie_base().calculer_numero(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s1, s2: s1._Signal6Sysam__lire_voie_base().tester_sysam() and s2._Signal6Sysam__lire_voie_base().tester_sysam() and not s1._Signal6Sysam__lire_voie_base().tester_compatibilite_nom(s2._Signal6Sysam__lire_voie_base()),
+            lambda p: p[0]._Signal6Sysam__lire_voie_base().calculer_numero(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_paires_signaux_noms_voies_ko:
             print("Problème de compatibilité entre les noms des paires de voies voie suivants:")
@@ -93,29 +93,29 @@ class Sysam3Test(Sysam2Mode):
 
         # tester entrees echantillonnés trop vite
         liste_entrees_echantillonnees_trop_vite = utb.lister_test(self.liste_entrees, 
-            lambda s: s.lire_base_de_temps().calculer_Te() < self.Te_entree_min,
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._PlotBase__lire_axe_x_base().lire_Xe() < self.Xe_entree_min,
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_entrees_echantillonnees_trop_vite:
-            print("Les entrees suivantes ne respectent pas Te > {0} s".format(self.Te_entree_min))
+            print("Les entrees suivantes ne respectent pas Xe > {0} s".format(self.Xe_entree_min))
             utb.print_liste(liste_entrees_echantillonnees_trop_vite, begin = " -> ")
             return False
 
         # tester sorties echantillonnées trop vite
         liste_sorties_echantillonnees_trop_vite = utb.lister_test(self.liste_sorties, 
-            lambda s: s.lire_base_de_temps().calculer_Te() < self.Te_sortie_min,
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._PlotBase__lire_axe_x_base().lire_Xe() < self.Xe_sortie_min,
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_sorties_echantillonnees_trop_vite:
-            print("Les sorties suivantes ne respectent pas Te > {0} s".format(self.Te_sortie_min))
+            print("Les sorties suivantes ne respectent pas Xe > {0} s".format(self.Xe_sortie_min))
             utb.print_liste(liste_sorties_echantillonnees_trop_vite, begin = " -> ")
             return False
 
         # tester compatibilités entre les bases de temps des entrées
         liste_paires_entrees_bases_de_temps_ko = utb.lister_paires_test(self.liste_entrees, 
-            lambda s1, s2: s1.lire_base_de_temps() != s2.lire_base_de_temps(),
-            lambda p: p[0].lire_voie_base().calculer_numero(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s1, s2: s1._PlotBase__lire_axe_x_base() != s2._PlotBase__lire_axe_x_base(),
+            lambda p: p[0]._Signal6Sysam__lire_voie_base().calculer_numero(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_paires_entrees_bases_de_temps_ko:
             print("Problème de compatibilité entre les bases de temps des paires d'entrées suivantes:")
@@ -125,8 +125,8 @@ class Sysam3Test(Sysam2Mode):
         # tester validite des bases de temps de sortie
         if "synchrone" in self.chaine_mode:
             liste_sorties_echantillonnage_ko = utb.lister_test(self.liste_sorties, 
-                lambda s: s.lire_base_de_temps().calculer_Te() != self.base_de_temps_entrees.calculer_Te(),
-                lambda s: s.lire_voie_base().calculer_numero()
+                lambda s: s._PlotBase__lire_axe_x_base().lire_Xe() != self.axe_x_base_entrees.lire_Xe(),
+                lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
                 )
             if liste_sorties_echantillonnage_ko:
                 print("Problème de périodes d'échantillonnage sur les sorties suivantes (ES synchrones):")
@@ -135,8 +135,8 @@ class Sysam3Test(Sysam2Mode):
 
         # tester si les sorties commencent à t=0
         liste_sorties_tardives = utb.lister_test(self.liste_sorties, 
-            lambda s: s.lire_base_de_temps().lire_iemin() != 0,
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._PlotBase__lire_axe_x_base().iemin != 0,
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
         if liste_sorties_tardives:
             print("Les sorties suivantes ne débutent pas à t=0:")
@@ -147,10 +147,10 @@ class Sysam3Test(Sysam2Mode):
         # tester espace memoire
         liste_signaux_sysam = utb.lister_test(
             self.liste_signaux, 
-            lambda s: s.lire_voie_base().tester_sysam(),
-            lambda s: s.lire_voie_base().calculer_numero()
+            lambda s: s._Signal6Sysam__lire_voie_base().tester_sysam(),
+            lambda s: s._Signal6Sysam__lire_voie_base().calculer_numero()
             )
-        liste_N_ech = [s.lire_base_de_temps().calculer_N() for s in liste_signaux_sysam]
+        liste_N_ech = [s._PlotBase__lire_axe_x_base().lire_N() for s in liste_signaux_sysam]
         if np.sum(liste_N_ech) > base.voie_base.N_ech_max:
             print("Trop d'échantillons stockés en mémoire (max = {0})".format(base.voie_base.N_ech_max))
             for i in range(len(liste_signaux_sysam)):
